//
//  ViewController.m
//  TonyAngRightSelectDemo
//
//  Created by TonyAng on 2017/2/24.
//  Copyright © 2017年 TonyAng. All rights reserved.
//

#import "ViewController.h"
#import "SelectAreaView.h"

@interface ViewController ()<UITableViewDelegate,UITableViewDataSource>
@property (nonatomic, strong) UITableView *myTableView;
@property (nonatomic, strong) SelectAreaView *selectAreaView;
@property (nonatomic, strong) UIView *shadowView;// 阴影
@end
#define color_default                       UIColorFromRGB(0x008cee)
#define UIColorFromRGB(rgbValue) [UIColor colorWithRed:((float)((rgbValue & 0xFF0000) >> 16))/255.0 green:((float)((rgbValue & 0xFF00) >> 8))/255.0 blue:((float)(rgbValue & 0xFF))/255.0 alpha:1.0]

#define ic_defa
@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    self.title = @"选择器";
    self.navigationController.navigationBar.barTintColor = color_default;
    self.navigationController.navigationBar.translucent = NO;
    [self.navigationController.navigationBar setTitleTextAttributes:@{NSForegroundColorAttributeName:[UIColor whiteColor]}];
    self.view.backgroundColor = UIColorFromRGB(0xeeeeee);
    [self createTableView];
}

-(void)createTableView{
    _myTableView = [[UITableView alloc] initWithFrame:CGRectZero style:UITableViewStylePlain];
    _myTableView.delegate = self;
    _myTableView.dataSource = self;
    [self.view addSubview:_myTableView];
    [_myTableView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.offset(0);
        make.bottom.offset(0);
        make.left.offset(0);
        make.right.offset(0);
    }];
}

#pragma mark -
#pragma mark 返回某个分区的单元格的高度
- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return kFit(45);
}

#pragma mark -
#pragma mark 返回有多少分区
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

#pragma mark -
#pragma mark 返回一个分区有多少行
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return 20;
}

#pragma mark -
#pragma mark 返回表的单元格对象
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString *identifer = @"identifer";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:identifer];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:identifer];
        // 设置单元格附件样式
        cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
    }
    cell.backgroundColor = [UIColor colorWithRed:0.95 green:0.95 blue:0.95 alpha:1];
    cell.textLabel.text = [NSString stringWithFormat:@"第%ld行",indexPath.row];
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    NSLog(@"你点击了第%ld分区第%ld行", indexPath.section ,indexPath.row);
    [tableView deselectRowAtIndexPath:indexPath animated:NO];
    if (self.selectAreaView) {
        [self.selectAreaView removeFromSuperview];
        [self.shadowView removeFromSuperview];
        [self createRightSelectAreaView];
    }else{
        [self createRightSelectAreaView];
    }
}
#pragma mark -
#pragma mark -------->选择
-(void)createRightSelectAreaView{
    //选择
    self.selectAreaView = [SelectAreaView new];
    self.selectAreaView = [[SelectAreaView alloc] initWithFrame:CGRectMake(screenWidth(), kFit(18.2), kFit(243), screenHeight() - kFit(18.2)) withParamsDic:nil];
    self.selectAreaView.backgroundColor = [UIColor whiteColor];
    [self.view.window addSubview:self.selectAreaView];
    
    @weakify(self)
    self.selectAreaView.selectAreaBlock = ^(NSString *areaString) {
        @strongify(self)
        NSLog(@"------------>%@",areaString);
        [self CreateCancle];
    };
    
    self.selectAreaView.closeAreaBlock = ^{
        @strongify(self)
        [self CreateCancle];
    };
    
    [UIView animateWithDuration:0.3 // 动画时长
                          delay:0.0 // 动画延迟
                        options:UIViewAnimationOptionCurveEaseIn // 动画过渡效果
                     animations:^{
                         self.selectAreaView.frame = CGRectMake(screenWidth() - kFit(243), kFit(18.2), kFit(243), screenHeight() - kFit(18.2));
                     }
                     completion:^(BOOL finished) {
                         // 动画完成后执行
                     }];
    //阴影
    self.shadowView = [UIView new];
    self.shadowView = [[UIView alloc] initWithFrame:CGRectMake(0, kFit(18.2),screenWidth() - kFit(243), screenHeight() - kFit(18.2))];
    self.shadowView.backgroundColor = [UIColor blackColor];
    self.shadowView.alpha = 0.3;
    [self.view.window addSubview:self.shadowView];
    // 单击的 Recognizer(share_lightView添加手势)
    UITapGestureRecognizer* singleRecognizer = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(shadowView_HandleSingleTapFromAction)];
    singleRecognizer.numberOfTapsRequired = 1; // 单击
    [self.shadowView addGestureRecognizer:singleRecognizer];
}

-(void)shadowView_HandleSingleTapFromAction{
    NSLog(@"隐藏");
    [self CreateCancle];
}

#pragma mark -
#pragma mark -------->取消
-(void)CreateCancle{
    [self.shadowView removeFromSuperview];
    [UIView animateWithDuration:0.3 // 动画时长
                          delay:0.0 // 动画延迟
                        options:UIViewAnimationOptionCurveEaseIn // 动画过渡效果
                     animations:^{
                         self.selectAreaView.frame = CGRectMake(screenWidth(), kFit(18.2), kFit(243), screenHeight() - kFit(18.2));
                     }
                     completion:^(BOOL finished) {
                         // 动画完成后执行
                         [self.selectAreaView removeFromSuperview];
                     }];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


@end
